@@ -9,7 +9,7 @@ use parent qw{Exporter};
 
 use Carp;
 use IO::Scalar;
-use ReadonlyX;
+use Readonly;
 
 Readonly::Scalar my $EMPTY => q{};
 
