@@ -5,17 +5,14 @@ use warnings;
 
 use parent qw( Exporter AWS::Signature4 );
 
-our $VERSION = '2.1.3';
+our $VERSION = '2.1.4';
 
-our @EXPORT_OK = qw{ parse_service_url };
+our @EXPORT_OK = qw( parse_service_url );
 
 our @SERVICE_URL_REGEXP = (
-  qr/(s3)[.]amazonaws[.]com\z/xsm,
-  qr/(s3)[.]([^.]+)[.]amazonaws[.]com\z/xsm,
-  qr/(s3)[.][^.]+[.]([^.]+)[.]amazonaws[.]com\z/xsm,
-  qr/(s3)[-][^.]+.+[.]([^.]+)[.]amazonaws[.]com\z/xsm,
-  qr/^([[:alpha:]-]+)[.]amazonaws[.]com\z/xsm,
-  qr/^([[:alpha:]-]+)[.]([^.]*)[.]amazonaws[.]com/xsm,
+  qr/(s3)[.]amazonaws[.]com\z/xsm,                   qr/(s3)[.]([^.]+)[.]amazonaws[.]com\z/xsm,
+  qr/(s3)[.][^.]+[.]([^.]+)[.]amazonaws[.]com\z/xsm, qr/(s3)[-][^.]+.+[.]([^.]+)[.]amazonaws[.]com\z/xsm,
+  qr/^([[:alpha:]-]+)[.]amazonaws[.]com\z/xsm,       qr/^([[:alpha:]-]+)[.]([^.]*)[.]amazonaws[.]com/xsm,
 );
 
 ########################################################################
@@ -33,7 +30,7 @@ sub new {
   @{$self}{@extra} = @args{@extra};
 
   return $self;
-} ## end sub new
+}
 
 ########################################################################
 sub parse_service_url {
@@ -46,18 +43,17 @@ sub parse_service_url {
   if ( !$service || !$region ) {
     foreach my $regexp (@SERVICE_URL_REGEXP) {
       if ( $host =~ $regexp ) {
-        #        print Dumper [ $host, $regexp ];
-
         $service = $1;
         $region  = $2 || $region || $default_region;
         last;
-      } ## end if ( $host =~ $regexp )
+      }
+    }
+  }
 
-    } ## end foreach my $regexp (@SERVICE_URL_REGEXP)
-  } ## end if ( !$service || !$region)
+  $region ||= $default_region;
 
   return ( $host, $service, $region );
-} ## end sub parse_service_url
+}
 
 ###############################################################
 sub scope {
@@ -84,7 +80,7 @@ sub _scope {
   );
 
   return "$date/$region/$service/aws4_request";
-} ## end sub _scope
+}
 
 1;
 
